/*
 * Title:        GridSim Toolkit
 * Description:  GridSim (Grid Simulation) Toolkit for Modeling and Simulation
 *               of Parallel and Distributed Systems such as Clusters and Grids
 * License:      GPL - http://www.gnu.org/copyleft/gpl.html
 */

package org.cloudbus.cloudsim.util;

import java.util.List;

import org.cloudbus.cloudsim.Cloudlet;

/**
 * This interface defines what a workload model should provide. A workload model
 * generates a list of jobs that can be dispatched to a resource by
 * {@link Workload}.
 * 
 * @author Marcos Dias de Assuncao
 * @since 5.0
 * 
 * @see Workload
 * @see WorkloadFileReader
 */
public interface WorkloadModel {

    /**
     * Returns a list with the jobs generated by the workload.
     * 
     * @return a list with the jobs generated by the workload.
     */
    List<Cloudlet> generateWorkload();
}
